ServerBuilder

Struct ServerBuilder 

pub struct ServerBuilder<T, P, R, C, L, I> { /* private fields */ }
Builder for constructing a composed MCP server.

Example

use rmcp_server_builder::ServerBuilder;
use rmcp::model::Implementation;

let server = ServerBuilder::new()
    .info(Implementation::from_build_env())
    .tools(my_tools_provider)
    .prompts(my_prompts_provider)
    .build();

Implementations

Source

impl ServerBuilder<Unset, Unset, Unset, Unset, Unset, Unset>

pub fn new() -> Self

Create a new server builder with no providers set.

Source

impl<T, P, R, C, L, I> ServerBuilder<T, P, R, C, L, I>

pub fn tools<NewT: ToolsProvider>( self, provider: NewT, ) -> ServerBuilder<NewT, P, R, C, L, I>

Set the tools provider.

pub fn prompts<NewP: PromptsProvider>( self, provider: NewP, ) -> ServerBuilder<T, NewP, R, C, L, I>

Set the prompts provider.

pub fn resources<NewR: ResourcesProvider>( self, provider: NewR, ) -> ServerBuilder<T, P, NewR, C, L, I>

Set the resources provider.

pub fn completion<NewC: CompletionProvider>( self, provider: NewC, ) -> ServerBuilder<T, P, R, NewC, L, I>

Set the completion provider.

pub fn logging<NewL: LoggingProvider>( self, provider: NewL, ) -> ServerBuilder<T, P, R, C, NewL, I>

Set the logging provider.

pub fn info<NewI: ServerInfoProvider>( self, provider: NewI, ) -> ServerBuilder<T, P, R, C, L, NewI>

Set the server info provider.

pub fn instructions(self, instructions: impl Into<String>) -> Self

Set human-readable instructions for using this server.

Source

impl<T, P, R, C, L, I> ServerBuilder<T, P, R, C, L, I>

pub fn build(self) -> Server<T, P, R, C, L, I>

Build the server.

This will use Unset for any providers that weren’t explicitly set, which will return “method not found” errors for those capabilities.